@@ -2,7 +2,7 @@
                           xmlcode.cpp  -  description
                              -------------------
     begin                : Mo 23.06.2008
-    copyright            : (C) 2008 by Andre Simon
+    copyright            : (C) 2008-2016 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -81,7 +81,7 @@ string SVGGenerator::getStyleDefinition()
            << ( docStyle.getBgColour().getBlue ( SVG ) )
            << "; } \n";
         os << "g { font-size: " << getBaseFontSize();
-        os << "; font-family: \"" << getBaseFont() << "\"; }\n";
+        os << "; font-family: " << getBaseFont() << "; }\n";
         os << getAttributes ( "text", docStyle.getDefaultStyle() )
            << getAttributes ( "tspan."+STY_NAME_NUM, docStyle.getNumberStyle() )
            << getAttributes ( "tspan."+STY_NAME_ESC, docStyle.getEscapeCharStyle() )
@@ -188,7 +188,7 @@ string SVGGenerator::getFooter()
 string SVGGenerator::maskCharacter ( unsigned  char c )
 {
     switch ( c ) {
-      case ' ' :
+    case ' ' :
         return spacer;
         break;
     case '<' :
