@@ -22,14 +22,14 @@
 #include <string>
 #include <vector>
 
-//-----------------------------------------------------------------------------
-// declarations
-//-----------------------------------------------------------------------------
-
 #ifdef __GNUC__
 	#include <cstring>              // need both string and cstring for GCC
 #endif
 
+//-----------------------------------------------------------------------------
+// declarations
+//-----------------------------------------------------------------------------
+
 #ifdef _MSC_VER
 	#pragma warning(disable: 4267)  // conversion from size_t to int
 #endif
@@ -84,30 +84,33 @@ enum FormatStyle
 	STYLE_LISP
 };
 
-enum BracketMode
+enum BraceMode
 {
 	NONE_MODE,
 	ATTACH_MODE,
 	BREAK_MODE,
 	LINUX_MODE,
-	RUN_IN_MODE		// broken brackets
+	RUN_IN_MODE		// broken braces
 };
 
-enum BracketType
+// maximun value for int is 16,384 (total value of 32,767)
+enum BraceType
 {
-	NULL_TYPE = 0,
-	NAMESPACE_TYPE = 1,			// also a DEFINITION_TYPE
-	CLASS_TYPE = 2,				// also a DEFINITION_TYPE
-	STRUCT_TYPE = 4,			// also a DEFINITION_TYPE
-	INTERFACE_TYPE = 8,			// also a DEFINITION_TYPE
-	DEFINITION_TYPE = 16,
-	COMMAND_TYPE = 32,
-	ARRAY_NIS_TYPE = 64,		// also an ARRAY_TYPE
-	ENUM_TYPE = 128,			// also an ARRAY_TYPE
-	INIT_TYPE = 256,			// also an ARRAY_TYPE
-	ARRAY_TYPE = 512,
-	EXTERN_TYPE = 1024,			// extern "C", not a command type extern
-	SINGLE_LINE_TYPE = 2048
+	NULL_TYPE        = 0,
+	NAMESPACE_TYPE   = 1,		// also a DEFINITION_TYPE
+	CLASS_TYPE       = 2,		// also a DEFINITION_TYPE
+	STRUCT_TYPE      = 4,		// also a DEFINITION_TYPE
+	INTERFACE_TYPE   = 8,		// also a DEFINITION_TYPE
+	DEFINITION_TYPE  = 16,
+	COMMAND_TYPE     = 32,
+	ARRAY_NIS_TYPE   = 64,		// also an ARRAY_TYPE
+	ENUM_TYPE        = 128,		// also an ARRAY_TYPE
+	INIT_TYPE        = 256,		// also an ARRAY_TYPE
+	ARRAY_TYPE       = 512,
+	EXTERN_TYPE      = 1024,	// extern "C", not a command type extern
+	EMPTY_BLOCK_TYPE = 2048,	// also a SINGLE_LINE_TYPE
+	BREAK_BLOCK_TYPE = 4096,	// also a SINGLE_LINE_TYPE
+	SINGLE_LINE_TYPE = 8192
 };
 
 enum MinConditional
@@ -138,10 +141,10 @@ enum PointerAlign
 
 enum ReferenceAlign
 {
-	REF_ALIGN_NONE = PTR_ALIGN_NONE,
-	REF_ALIGN_TYPE = PTR_ALIGN_TYPE,
+	REF_ALIGN_NONE   = PTR_ALIGN_NONE,
+	REF_ALIGN_TYPE   = PTR_ALIGN_TYPE,
 	REF_ALIGN_MIDDLE = PTR_ALIGN_MIDDLE,
-	REF_ALIGN_NAME = PTR_ALIGN_NAME,
+	REF_ALIGN_NAME   = PTR_ALIGN_NAME,
 	REF_SAME_AS_PTR
 };
 
@@ -216,6 +219,7 @@ public:
 	static const string _AS_TRY, _AS_FINALLY, _AS_EXCEPT;
 	static const string AS_PUBLIC, AS_PROTECTED, AS_PRIVATE;
 	static const string AS_CLASS, AS_STRUCT, AS_UNION, AS_INTERFACE, AS_NAMESPACE;
+	static const string AS_MODULE;
 	static const string AS_END;
 	static const string AS_SELECTOR;
 	static const string AS_EXTERN, AS_ENUM;
@@ -223,10 +227,10 @@ public:
 	static const string AS_NOEXCEPT, AS_INTERRUPT, AS_AUTORELEASEPOOL;
 	static const string AS_WHERE, AS_LET, AS_SYNCHRONIZED;
 	static const string AS_OPERATOR, AS_TEMPLATE;
-	static const string AS_OPEN_BRACKET, AS_CLOSE_BRACKET;
+	static const string AS_OPEN_BRACE, AS_CLOSE_BRACE;
 	static const string AS_OPEN_LINE_COMMENT, AS_OPEN_COMMENT, AS_CLOSE_COMMENT;
 	static const string AS_BAR_DEFINE, AS_BAR_INCLUDE, AS_BAR_IF, AS_BAR_EL, AS_BAR_ENDIF;
-	static const string AS_RETURN;
+	static const string AS_AUTO, AS_RETURN;
 	static const string AS_CIN, AS_COUT, AS_CERR;
 	static const string AS_ASSIGN, AS_PLUS_ASSIGN, AS_MINUS_ASSIGN, AS_MULT_ASSIGN;
 	static const string AS_DIV_ASSIGN, AS_MOD_ASSIGN, AS_XOR_ASSIGN, AS_OR_ASSIGN, AS_AND_ASSIGN;
@@ -322,7 +326,7 @@ public:
 	string getIndentString() const;
 	string getNextWord(const string& line, size_t currPos) const;
 	bool getAlignMethodColon() const;
-	bool getBracketIndent() const;
+	bool getBraceIndent() const;
 	bool getBlockIndent() const;
 	bool getCaseIndent() const;
 	bool getClassIndent() const;
@@ -341,18 +345,18 @@ protected:
 	const string* findOperator(const string& line, int i,
 	                           const vector<const string*>* possibleOperators) const;
 	int  getNextProgramCharDistance(const string& line, int i) const;
-	int  indexOf(vector<const string*>& container, const string* element) const;
+	int  indexOf(const vector<const string*>& container, const string* element) const;
 	void setBlockIndent(bool state);
-	void setBracketIndent(bool state);
-	void setBracketIndentVtk(bool state);
+	void setBraceIndent(bool state);
+	void setBraceIndentVtk(bool state);
 	string extractPreprocessorStatement(const string& line) const;
 	string trim(const string& str) const;
 	string rtrim(const string& str) const;
 
 	// variables set by ASFormatter - must be updated in activeBeautifierStack
 	int  inLineNumber;
-	int  horstmannIndentInStatement;
-	int  nonInStatementBracket;
+	int  runInIndentInStatement;
+	int  nonInStatementBrace;
 	int  objCColonAlignSubsequent;		// for subsequent lines not counting indent
 	bool lineCommentNoBeautify;
 	bool isElseHeaderIndent;
@@ -367,8 +371,10 @@ protected:
 
 private:  // functions
 	ASBeautifier(const ASBeautifier& other);     // inline functions
-	ASBeautifier& operator=(ASBeautifier&);     // not to be implemented
+	ASBeautifier& operator=(ASBeautifier&);      // not to be implemented
 
+	void adjustObjCMethodDefinitionIndentation(const string& line_);
+	void adjustObjCMethodCallIndentation(const string& line_);
 	void adjustParsedLineIndentation(size_t iPrelim, bool isInExtraHeaderIndent);
 	void computePreliminaryIndentation();
 	void parseCurrentLine(const string& line);
@@ -384,16 +390,18 @@ private:  // functions
 	void deleteBeautifierContainer(vector<ASBeautifier*>*& container);
 	void deleteTempStacksContainer(vector<vector<const string*>*>*& container);
 	int  adjustIndentCountForBreakElseIfComments() const;
-	int  computeObjCColonAlignment(string& line, int colonAlignPosition) const;
+	int  computeObjCColonAlignment(const string& line, int colonAlignPosition) const;
 	int  convertTabToSpaces(int i, int tabIncrementIn) const;
 	int  getInStatementIndentAssign(const string& line, size_t currPos) const;
 	int  getInStatementIndentComma(const string& line, size_t currPos) const;
+	int  getObjCFollowingKeyword(const string& line, int bracePos) const;
 	bool isIndentedPreprocessor(const string& line, size_t currPos) const;
 	bool isLineEndComment(const string& line, int startPos) const;
 	bool isPreprocessorConditionalCplusplus(const string& line) const;
 	bool isInPreprocessorUnterminatedComment(const string& line);
 	bool statementEndsWithComma(const string& line, int index) const;
-	string& getIndentedLineReturn(string& newLine, const string& originalLine) const;
+	const string& getIndentedLineReturn(const string& newLine, const string& originalLine) const;
+	string getIndentedSpaceEquivalent(const string& line_) const;
 	string preLineWS(int lineIndentCount, int lineSpaceIndentCount) const;
 	template<typename T> void deleteContainer(T& container);
 	template<typename T> void initContainer(T& container, T value);
@@ -416,10 +424,10 @@ private:  // variables
 	vector<int>* activeBeautifierStackLengthStack;
 	vector<const string*>* headerStack;
 	vector<vector<const string*>* >* tempStacks;
-	vector<int>* blockParenDepthStack;
+	vector<int>* squareBracketDepthStack;
 	vector<bool>* blockStatementStack;
 	vector<bool>* parenStatementStack;
-	vector<bool>* bracketBlockStateStack;
+	vector<bool>* braceBlockStateStack;
 	vector<int>* inStatementIndentStack;
 	vector<int>* inStatementIndentStackSizeStack;
 	vector<int>* parenIndentStack;
@@ -440,7 +448,7 @@ private:  // variables
 	bool isInAsmBlock;
 	bool isInComment;
 	bool isInPreprocessorComment;
-	bool isInHorstmannComment;
+	bool isInRunInComment;
 	bool isInCase;
 	bool isInQuestion;
 	bool isInStatement;
@@ -450,12 +458,15 @@ private:  // variables
 	bool isInDefineDefinition;
 	bool classIndent;
 	bool isIndentModeOff;
-	bool isInClassHeader;			// is in a class before the opening bracket
+	bool isInClassHeader;			// is in a class before the opening brace
 	bool isInClassHeaderTab;		// is in an indentable class header line
 	bool isInClassInitializer;		// is in a class after the ':' initializer
-	bool isInClass;					// is in a class after the opening bracket
+	bool isInClass;					// is in a class after the opening brace
 	bool isInObjCMethodDefinition;
+	bool isInObjCMethodCall;
+	bool isInObjCMethodCallFirst;
 	bool isImmediatelyPostObjCMethodDefinition;
+	bool isImmediatelyPostObjCMethodCall;
 	bool isInIndentablePreprocBlock;
 	bool isInObjCInterface;
 	bool isInEnum;
@@ -465,8 +476,8 @@ private:  // variables
 	bool switchIndent;
 	bool caseIndent;
 	bool namespaceIndent;
-	bool bracketIndent;
-	bool bracketIndentVtk;
+	bool braceIndent;
+	bool braceIndentVtk;
 	bool blockIndent;
 	bool labelIndent;
 	bool shouldIndentPreprocDefine;
@@ -481,12 +492,12 @@ private:  // variables
 	bool blockCommentNoIndent;
 	bool blockCommentNoBeautify;
 	bool previousLineProbationTab;
-	bool lineBeginsWithOpenBracket;
-	bool lineBeginsWithCloseBracket;
+	bool lineBeginsWithOpenBrace;
+	bool lineBeginsWithCloseBrace;
 	bool lineBeginsWithComma;
 	bool lineIsCommentOnly;
 	bool lineIsLineCommentOnly;
-	bool shouldIndentBrackettedLine;
+	bool shouldIndentBracedLine;
 	bool isInSwitch;
 	bool foundPreCommandHeader;
 	bool foundPreCommandMacro;
@@ -494,8 +505,9 @@ private:  // variables
 	bool shouldIndentPreprocConditional;
 	int  indentCount;
 	int  spaceIndentCount;
-	int  spaceIndentObjCMethodDefinition;
-	int  colonIndentObjCMethodDefinition;
+	int  spaceIndentObjCMethodAlignment;
+	int  bracePosObjCMethodAlignment;
+	int  colonIndentObjCMethodAlignment;
 	int  lineOpeningBlocksNum;
 	int  lineClosingBlocksNum;
 	int  fileType;
@@ -535,16 +547,16 @@ public:  // functions
 	void enhance(string& line, bool isInNamespace, bool isInPreprocessor, bool isInSQL);
 
 private:  // functions
-	void    convertForceTabIndentToSpaces(string&  line) const;
-	void    convertSpaceIndentToForceTab(string& line) const;
-	size_t  findCaseColon(string&  line, size_t caseIndex) const;
-	int     indentLine(string&  line, int indent) const;
-	bool    isBeginDeclareSectionSQL(string&  line, size_t index) const;
-	bool    isEndDeclareSectionSQL(string&  line, size_t index) const;
-	bool    isOneLineBlockReached(string& line, int startChar) const;
-	void    parseCurrentLine(string& line, bool isInPreprocessor, bool isInSQL);
-	size_t  processSwitchBlock(string&  line, size_t index);
-	int     unindentLine(string&  line, int unindent) const;
+	void   convertForceTabIndentToSpaces(string&  line) const;
+	void   convertSpaceIndentToForceTab(string& line) const;
+	size_t findCaseColon(const string&  line, size_t caseIndex) const;
+	int    indentLine(string&  line, int indent) const;
+	bool   isBeginDeclareSectionSQL(const string&  line, size_t index) const;
+	bool   isEndDeclareSectionSQL(const string&  line, size_t index) const;
+	bool   isOneLineBlockReached(const string& line, int startChar) const;
+	void   parseCurrentLine(string& line, bool isInPreprocessor, bool isInSQL);
+	size_t processSwitchBlock(string&  line, size_t index);
+	int    unindentLine(string&  line, int unindent) const;
 
 private:
 	// options from command line or options file
@@ -565,10 +577,10 @@ private:
 	char quoteChar;
 
 	// unindent variables
-	int  bracketCount;
+	int  braceCount;
 	int  switchDepth;
 	int  eventPreprocDepth;
-	bool lookingForCaseBracket;
+	bool lookingForCaseBrace;
 	bool unindentNextLine;
 	bool shouldUnindentLine;
 	bool shouldUnindentComment;
@@ -577,7 +589,7 @@ private:
 	// contains variables used to unindent the case blocks
 	struct SwitchVariables
 	{
-		int  switchBracketCount;
+		int  switchBraceCount;
 		int  unindentDepth;
 		bool unindentCase;
 	};
@@ -611,20 +623,23 @@ public:	// functions
 	LineEndFormat getLineEndFormat() const;
 	bool getIsLineReady() const;
 	void setFormattingStyle(FormatStyle style);
-	void setAddBracketsMode(bool state);
-	void setAddOneLineBracketsMode(bool state);
-	void setRemoveBracketsMode(bool state);
+	void setAddBracesMode(bool state);
+	void setAddOneLineBracesMode(bool state);
+	void setRemoveBracesMode(bool state);
 	void setAttachClass(bool state);
+	void setAttachClosingWhile(bool state);
 	void setAttachExternC(bool state);
 	void setAttachNamespace(bool state);
 	void setAttachInline(bool state);
-	void setBracketFormatMode(BracketMode mode);
+	void setBraceFormatMode(BraceMode mode);
 	void setBreakAfterMode(bool state);
-	void setBreakClosingHeaderBracketsMode(bool state);
+	void setBreakClosingHeaderBracesMode(bool state);
 	void setBreakBlocksMode(bool state);
 	void setBreakClosingHeaderBlocksMode(bool state);
 	void setBreakElseIfsMode(bool state);
 	void setBreakOneLineBlocksMode(bool state);
+	void setBreakOneLineHeadersMode(bool state);
+	void setBreakOneLineStatementsMode(bool state);
 	void setMethodPrefixPaddingMode(bool state);
 	void setMethodPrefixUnPaddingMode(bool state);
 	void setReturnTypePaddingMode(bool state);
@@ -647,13 +662,20 @@ public:	// functions
 	void setPointerAlignment(PointerAlign alignment);
 	void setPreprocBlockIndent(bool state);
 	void setReferenceAlignment(ReferenceAlign alignment);
-	void setSingleStatementsMode(bool state);
 	void setStripCommentPrefix(bool state);
 	void setTabSpaceConversionMode(bool state);
 	size_t getChecksumIn() const;
 	size_t getChecksumOut() const;
 	int  getChecksumDiff() const;
 	int  getFormatterFileType() const;
+	// retained for compatability with release 2.06
+	// "Brackets" have been changed to "Braces" in 2.7
+	// they are referenced only by the old "bracket" options
+	void setAddBracketsMode(bool state);
+	void setAddOneLineBracketsMode(bool state);
+	void setRemoveBracketsMode(bool state);
+	void setBreakClosingHeaderBracketsMode(bool state);
+
 
 private:  // functions
 	ASFormatter(const ASFormatter& copy);       // not to be implemented
@@ -661,12 +683,12 @@ private:  // functions
 	template<typename T> void deleteContainer(T& container);
 	template<typename T> void initContainer(T& container, T value);
 	char peekNextChar() const;
-	BracketType getBracketType();
+	BraceType getBraceType();
 	bool adjustChecksumIn(int adjustment);
 	bool computeChecksumIn(const string& currentLine_);
 	bool computeChecksumOut(const string& beautifiedLine);
-	bool addBracketsToStatement();
-	bool removeBracketsFromStatement();
+	bool addBracesToStatement();
+	bool removeBracesFromStatement();
 	bool commentAndHeaderFollows();
 	bool getNextChar();
 	bool getNextLine(bool emptyLineWasDeleted = false);
@@ -675,40 +697,42 @@ private:  // functions
 	bool isBeforeAnyComment() const;
 	bool isBeforeAnyLineEndComment(int startPos) const;
 	bool isBeforeMultipleLineEndComments(int startPos) const;
-	bool isBracketType(BracketType a, BracketType b) const;
+	bool isBraceType(BraceType a, BraceType b) const;
 	bool isClassInitializer() const;
 	bool isClosingHeader(const string* header) const;
-	bool isCurrentBracketBroken() const;
+	bool isCurrentBraceBroken() const;
 	bool isDereferenceOrAddressOf() const;
-	bool isExecSQL(string& line, size_t index) const;
+	bool isExecSQL(const string& line, size_t index) const;
 	bool isEmptyLine(const string& line) const;
 	bool isExternC() const;
+	bool isMultiStatementLine() const;
 	bool isNextWordSharpNonParenHeader(int startChar) const;
-	bool isNonInStatementArrayBracket() const;
+	bool isNonInStatementArrayBrace() const;
 	bool isOkToSplitFormattedLine();
 	bool isPointerOrReference() const;
 	bool isPointerOrReferenceCentered() const;
-	bool isPointerOrReferenceVariable(string& word) const;
+	bool isPointerOrReferenceVariable(const string& word) const;
 	bool isSharpStyleWithParen(const string* header) const;
-	bool isStructAccessModified(string& firstLine, size_t index) const;
-	bool isIndentablePreprocessorBlock(string& firstLine, size_t index);
-	bool isNDefPreprocStatement(string& nextLine_, string& preproc) const;
+	bool isStructAccessModified(const string& firstLine, size_t index) const;
+	bool isIndentablePreprocessorBlock(const string& firstLine, size_t index);
+	bool isNDefPreprocStatement(const string& nextLine_, const string& preproc) const;
 	bool isUnaryOperator() const;
-	bool isUniformInitializerBracket() const;
+	bool isUniformInitializerBrace() const;
 	bool isImmediatelyPostCast() const;
 	bool isInExponent() const;
 	bool isInSwitchStatement() const;
-	bool isNextCharOpeningBracket(int startChar) const;
-	bool isOkToBreakBlock(BracketType bracketType) const;
+	bool isNextCharOpeningBrace(int startChar) const;
+	bool isOkToBreakBlock(BraceType braceType) const;
 	bool isOperatorPaddingDisabled() const;
 	bool pointerSymbolFollows() const;
 	int  findObjCColonAlignment() const;
 	int  getCurrentLineCommentAdjustment();
 	int  getNextLineCommentAdjustment();
-	int  isOneLineBlockReached(string& line, int startChar) const;
+	int  isOneLineBlockReached(const string& line, int startChar) const;
 	void adjustComments();
 	void appendChar(char ch, bool canBreakLine);
 	void appendCharInsideComments();
+	void appendClosingHeader();
 	void appendOperator(const string& sequence, bool canBreakLine = true);
 	void appendSequence(const string& sequence, bool canBreakLine = true);
 	void appendSpacePad();
@@ -720,17 +744,17 @@ private:  // functions
 	void checkIfTemplateOpener();
 	void clearFormattedLineSplitPoints();
 	void convertTabToSpaces();
-	void deleteContainer(vector<BracketType>*& container);
+	void deleteContainer(vector<BraceType>*& container);
 	void formatArrayRunIn();
 	void formatRunIn();
-	void formatArrayBrackets(BracketType bracketType, bool isOpeningArrayBracket);
-	void formatClosingBracket(BracketType bracketType);
+	void formatArrayBraces(BraceType braceType, bool isOpeningArrayBrace);
+	void formatClosingBrace(BraceType braceType);
 	void formatCommentBody();
 	void formatCommentOpener();
 	void formatCommentCloser();
 	void formatLineCommentBody();
 	void formatLineCommentOpener();
-	void formatOpeningBracket(BracketType bracketType);
+	void formatOpeningBrace(BraceType braceType);
 	void formatQuoteBody();
 	void formatQuoteOpener();
 	void formatPointerOrReference();
@@ -741,7 +765,7 @@ private:  // functions
 	void fixOptionVariableConflicts();
 	void goForward(int i);
 	void isLineBreakBeforeClosingHeader();
-	void initContainer(vector<BracketType>*& container, vector<BracketType>* value);
+	void initContainer(vector<BraceType>*& container, vector<BraceType>* value);
 	void initNewLine();
 	void padObjCMethodColon();
 	void padObjCMethodPrefix();
@@ -751,13 +775,13 @@ private:  // functions
 	void padParens();
 	void processPreprocessor();
 	void resetEndOfStatement();
-	void setAttachClosingBracketMode(bool state);
+	void setAttachClosingBraceMode(bool state);
 	void stripCommentPrefix();
 	void testForTimeToSplitFormattedLine();
 	void trimContinuationLine();
 	void updateFormattedLineSplitPointsPointerOrReference(size_t index);
 	size_t findFormattedLineSplitPoint() const;
-	size_t findNextChar(string& line, char searchChar, int searchStart = 0) const;
+	size_t findNextChar(const string& line, char searchChar, int searchStart = 0) const;
 	const string* checkForHeaderFollowingComment(const string& firstLine) const;
 	const string* getFollowingOperator() const;
 	string getPreviousWord(const string& line, int currPos) const;
@@ -777,8 +801,8 @@ private:  // variables
 	ASSourceIterator* sourceIterator;
 	ASEnhancer* enhancer;
 
-	vector<const string*>* preBracketHeaderStack;
-	vector<BracketType>* bracketTypeStack;
+	vector<const string*>* preBraceHeaderStack;
+	vector<BraceType>* braceTypeStack;
 	vector<int>* parenStack;
 	vector<bool>* structStack;
 	vector<bool>* questionMarkStack;
@@ -796,17 +820,17 @@ private:  // variables
 	char quoteChar;
 	streamoff preprocBlockEnd;
 	int  charNum;
-	int  horstmannIndentChars;
+	int  runInIndentChars;
 	int  nextLineSpacePadNum;
 	int  objCColonAlign;
-	int  preprocBracketTypeStackSize;
+	int  preprocBraceTypeStackSize;
 	int  spacePadNum;
 	int  tabIncrementIn;
 	int  templateDepth;
 	int  squareBracketCount;
 	size_t checksumIn;
 	size_t checksumOut;
-	size_t currentLineFirstBracketNum;	// first bracket location on currentLine
+	size_t currentLineFirstBraceNum;	// first brace location on currentLine
 	size_t formattedLineCommentNum;     // comment location on formattedLine
 	size_t leadingSpaces;
 	size_t maxCodeLength;
@@ -825,13 +849,14 @@ private:  // variables
 
 	size_t previousReadyFormattedLineLength;
 	FormatStyle formattingStyle;
-	BracketMode bracketFormatMode;
-	BracketType previousBracketType;
+	BraceMode braceFormatMode;
+	BraceType previousBraceType;
 	PointerAlign pointerAlignment;
 	ReferenceAlign referenceAlignment;
 	ObjCColonPad objCColonPadMode;
 	LineEndFormat lineEnd;
 	bool isVirgin;
+	bool isInVirginLine;
 	bool shouldPadCommas;
 	bool shouldPadOperators;
 	bool shouldPadParensOutside;
@@ -847,6 +872,7 @@ private:  // variables
 	bool shouldAttachExternC;
 	bool shouldAttachNamespace;
 	bool shouldAttachClass;
+	bool shouldAttachClosingWhile;
 	bool shouldAttachInline;
 	bool isInLineComment;
 	bool isInComment;
@@ -878,6 +904,7 @@ private:  // variables
 	bool foundInterfaceHeader;
 	bool foundPreCommandHeader;
 	bool foundPreCommandMacro;
+	bool foundTrailingReturnType;
 	bool foundCastOperator;
 	bool isInLineBreak;
 	bool endOfAsmReached;
@@ -892,7 +919,7 @@ private:  // variables
 	bool isLineReady;
 	bool elseHeaderFollowsComments;
 	bool caseHeaderFollowsComments;
-	bool isPreviousBracketBlockRelated;
+	bool isPreviousBraceBlockRelated;
 	bool isInPotentialCalculation;
 	bool isCharImmediatelyPostComment;
 	bool isPreviousCharPostComment;
@@ -910,28 +937,29 @@ private:  // variables
 	bool isInObjCReturnType;
 	bool isInObjCSelector;
 	bool breakCurrentOneLineBlock;
-	bool shouldRemoveNextClosingBracket;
-	bool isInHorstmannRunIn;
-	bool currentLineBeginsWithBracket;
-	bool attachClosingBracketMode;
+	bool shouldRemoveNextClosingBrace;
+	bool isInBraceRunIn;
+	bool currentLineBeginsWithBrace;
+	bool attachClosingBraceMode;
 	bool shouldBreakOneLineBlocks;
-	bool shouldReparseCurrentChar;
+	bool shouldBreakOneLineHeaders;
 	bool shouldBreakOneLineStatements;
-	bool shouldBreakClosingHeaderBrackets;
+	bool shouldBreakClosingHeaderBraces;
 	bool shouldBreakElseIfs;
 	bool shouldBreakLineAfterLogical;
-	bool shouldAddBrackets;
-	bool shouldAddOneLineBrackets;
-	bool shouldRemoveBrackets;
+	bool shouldAddBraces;
+	bool shouldAddOneLineBraces;
+	bool shouldRemoveBraces;
 	bool shouldPadMethodColon;
 	bool shouldPadMethodPrefix;
+	bool shouldReparseCurrentChar;
 	bool shouldUnPadMethodPrefix;
 	bool shouldPadReturnType;
 	bool shouldUnPadReturnType;
 	bool shouldPadParamType;
 	bool shouldUnPadParamType;
 	bool shouldDeleteEmptyLines;
-	bool needHeaderOpeningBracket;
+	bool needHeaderOpeningBrace;
 	bool shouldBreakLineAtNextChar;
 	bool shouldKeepLineUnbroken;
 	bool passedSemicolon;
@@ -956,7 +984,7 @@ private:  // variables
 	bool isIndentableProprocessor;
 	bool isIndentableProprocessorBlock;
 	bool prependEmptyLine;
-	bool appendOpeningBracket;
+	bool appendOpeningBrace;
 	bool foundClosingHeader;
 	bool isInHeader;
 	bool isImmediatelyPostHeader;
@@ -998,7 +1026,7 @@ private:  // inline functions
 bool sortOnLength(const string* a, const string* b);
 bool sortOnName(const string* a, const string* b);
 
-}   // end of astyle namespace
+}   // namespace astyle
 
 // end of astyle namespace  --------------------------------------------------
 
